@@ -21,6 +21,7 @@ COPYRIGHT distributed with the source files.
 #include "buffers.h"
 #include "filesend.h"
 #include "modeless_dialogs.h"
+#include "char_funcs.h"
 
 extern Prog_func prog_func;
 
@@ -39,7 +40,7 @@ MainScreen::timer_event_handler() with it.
 */
 
 void EventSlots::about_kamplus(void) {
-  const char message[] = "kamplus-gtk-1.1.1a\n"
+  const char message[] = "kamplus-gtk-1.1.2a\n"
                          "Copyright (C) 1999 - 2002 Chris Vine, G3XXF\n"
                          "chris@cvine.freeserve.co.uk\n"
                          "G3XXF@GB7MSW.#33.GBR.EU\n\n"
@@ -299,6 +300,7 @@ void EventSlots::run_connect_script(const char* script) {
 	  exit(MEM_ERROR);
 	}
 	delete[] message;
+	script_file.clear();
 	script_file.close();
       }
       
@@ -325,6 +327,7 @@ void EventSlots::run_connect_script(const char* script) {
 	   && tnc_p->tnc_func.disconnect_stream.port == tnc_p->tnc_func.active_port
 	   && tnc_p->tnc_func.disconnect_stream.stream == tnc_p->tnc_func.active_stream()) {
     connect_script_flag = not_running;
+    script_file.clear();
     script_file.close();
   }
   
@@ -352,6 +355,7 @@ void EventSlots::run_connect_script(const char* script) {
       if (!script_file) script_file.clear(); // clear failbit - the line was longer than 256
     }
     if (!script_file) {              // finished sending script
+      script_file.clear();
       script_file.close();
       connect_script_flag = not_running;
     }
@@ -362,6 +366,7 @@ void EventSlots::run_connect_script(const char* script) {
   else if (connect_script_flag == running
 	   && time(0) - connect_script_timeout_base > 60) {
     connect_script_flag = not_running;
+    script_file.clear();
     script_file.close();
     tnc_p->send_kamcommand(packet_disconnectCMD);
     receivewin_p->write("Connect script timed out after 60 seconds");
@@ -465,8 +470,8 @@ void EventSlots::send_parms(const char*  file) {
       if (!parm_file) parm_file.clear(); // clear failbit - the line was longer than 256
     }
     else {  // we have sent all the commands in tnc.parms
-      parm_file.close();
       parm_file.clear();
+      parm_file.close();
       send_parms_flag = not_running;
     }
   }
@@ -540,6 +545,7 @@ void EventSlots::send_message_preprocess(int message_number, bool prompt_flag) {
     }
   }
   if (!message_found) {
+    message_file.clear();
     message_file.close();
     beep();
   }
@@ -604,11 +610,11 @@ void EventSlots::send_message(int message_number, bool send) {
 		      && (tnc_p->tnc_func.stream_status[0][1] == Tnc_func::disconnected
 			  || tnc_p->tnc_func.tor_connected_mode == Tnc_func::not_pactor_gtor))) {
 		if (!is_baudot(letter)) letter = 0;
-		else if (tnc_p->tnc_func.hfmode == Tnc_func::rtty) letter = toupper(letter);
+		else if (tnc_p->tnc_func.hfmode == Tnc_func::rtty) letter = toupper(static_cast<unsigned char> (letter));
 	      }
 	      else if (tnc_p->tnc_func.hfmode == Tnc_func::cw) {
 		if (!is_morse(letter) && letter != '$') letter = 0; // allow the $ token through
-		else letter = toupper(letter);
+		else letter = toupper(static_cast<unsigned char> (letter));
 	      }
 	    }
 
@@ -707,6 +713,7 @@ void EventSlots::send_message(int message_number, bool send) {
       }
     }
   }
+  message_file.clear();
   message_file.close();
 }
 
@@ -847,6 +854,7 @@ void EventSlots::change_hfmode(int mode) {
       && (tnc_p->tnc_func.hfmode == Tnc_func::packet // we must be changing from Packet to Tor
 	  || mode == Tnc_func::packet)) {     // we must be changing from Tor to packet
     tnc_p->tnc_func.capturefile_flag = false;
+    tnc_p->tnc_func.capturefile.clear();
     tnc_p->tnc_func.capturefile.close();
     mainscreen_p->display_capture_status();
   }
@@ -902,6 +910,7 @@ void EventSlots::capture(void) {
 // proceed
   if (tnc_p->tnc_func.capturefile_flag) {
     tnc_p->tnc_func.capturefile_flag = false;
+    tnc_p->tnc_func.capturefile.clear();
     tnc_p->tnc_func.capturefile.close();
   }
 
@@ -1309,12 +1318,12 @@ void EventSlots::send_letter(uchar letter) {
 	    && (tnc_p->tnc_func.stream_status[0][1] == Tnc_func::disconnected
 		|| tnc_p->tnc_func.tor_connected_mode == Tnc_func::not_pactor_gtor))) {
       if (!is_baudot((char)letter) && letter != 8) letter = 0;
-      else if (tnc_p->tnc_func.hfmode == Tnc_func::rtty) letter = toupper(letter);
+      else if (tnc_p->tnc_func.hfmode == Tnc_func::rtty) letter = toupper(static_cast<unsigned char> (letter));
     }
     
     else if (tnc_p->tnc_func.hfmode == Tnc_func::cw) {
       if (!is_morse((char)letter) && letter != 8) letter = 0;
-      else letter = toupper(letter);
+      else letter = toupper(static_cast<unsigned char> (letter));
     }
   }
   
@@ -1811,7 +1820,7 @@ void EventSlots::read_settings(void) {
 	// look for "MY_CALL:"
 	if (get_prog_parm("MY_CALL:", file_read, new_call)) {
 	  transform(new_call.begin(), new_call.end(),
-		    new_call.begin(), std::toupper);
+		    new_call.begin(), to_upper);
 	  if (new_pktcall.empty()) { // only overwrite new_pktcall if no PKT_CALL: yet specified
 	    new_pktcall = new_call;
 	  }
@@ -1820,13 +1829,13 @@ void EventSlots::read_settings(void) {
 	// look for "PKT_CALL:"
 	else if (get_prog_parm("PKT_CALL:", file_read, new_pktcall)) {
 	  transform(new_pktcall.begin(), new_pktcall.end(),
-		    new_pktcall.begin(), std::toupper);
+		    new_pktcall.begin(), to_upper);
 	}
 	    
 	// look for "SELCALL:"
 	else if (get_prog_parm("SELCALL:", file_read, new_selcall)) {
 	  transform(new_selcall.begin(), new_selcall.end(),
-		    new_selcall.begin(), std::toupper);
+		    new_selcall.begin(), to_upper);
 	}
 	
 	// look for "FILEDIR:"
