@@ -95,6 +95,7 @@ bool FilesendBuffer::load_buffer(void) {
 	receivewin_ptr->write("\nSending completed.\n", get_stream(), get_port());
       }
       file_flag = not_sending;
+      filein.clear();
       filein.close();
       return false;
     }
@@ -125,12 +126,12 @@ bool FilesendBuffer::load_buffer(void) {
 	      && (tnc_ptr->tnc_func.stream_status[0][1] == Tnc_func::disconnected
 		  || tnc_ptr->tnc_func.tor_connected_mode == Tnc_func::not_pactor_gtor))) {
 	if (!is_baudot(letter)) letter = 0;
-	else if (tnc_ptr->tnc_func.hfmode == Tnc_func::rtty) letter = toupper(letter);
+	else if (tnc_ptr->tnc_func.hfmode == Tnc_func::rtty) letter = toupper(static_cast<unsigned char> (letter));
       }
       else if (tnc_ptr->tnc_func.hfmode == Tnc_func::cw) {
 	if (!is_morse(letter) 
 	    && !(letter == '$' && convert_codes_flag)) letter = 0; // allow the $ token through
-	else letter = toupper(letter);
+	else letter = toupper(static_cast<unsigned char> (letter));
       }
     }
     
@@ -660,6 +661,7 @@ bool CqsendBuffer::load_buffer(void) {
     // then we need to end the autocq
     if (tnc_ptr->tnc_func.stream_status[0][1] ==  Tnc_func::connected
 	|| tnc_ptr->tnc_func.hfmode == Tnc_func::packet) {
+      filein.clear();
       filein.close();
       prog_func.sending_autocq = false;
       mainscreen_ptr->display_connected_status();
@@ -682,6 +684,7 @@ bool CqsendBuffer::load_buffer(void) {
     }
   }
   else if (autocq_flag == close_down) {
+    filein.clear();
     filein.close();
     prog_func.sending_autocq = false;
     mainscreen_ptr->display_connected_status();
