@@ -44,6 +44,7 @@ COPYRIGHT distributed with the source files.
 #include "pipes.h"
 #include "tnc.h"
 #include "settings.h"
+#include "char_funcs.h"
 
 ///////////////////////// function declarations //////////////////////
 
@@ -459,7 +460,7 @@ void configure_program(int& speed, string& port, int& vhf_paclen, int& hf_paclen
 	    // look for "MY_CALL:"
 	    if (get_prog_parm("MY_CALL:", file_read, prog_func.myCall)) {
 	        transform(prog_func.myCall.begin(), prog_func.myCall.end(),
-			  prog_func.myCall.begin(), std::toupper);
+			  prog_func.myCall.begin(), to_upper);
 	        if (prog_func.myPktCall.empty()) { // only overwrite myPktCall if no PKT_CALL: yet specified
 		    prog_func.myPktCall = prog_func.myCall;
 		}
@@ -468,13 +469,13 @@ void configure_program(int& speed, string& port, int& vhf_paclen, int& hf_paclen
 	    // look for "PKT_CALL:"
 	    else if (get_prog_parm("PKT_CALL:", file_read, prog_func.myPktCall)) {
 	        transform(prog_func.myPktCall.begin(), prog_func.myPktCall.end(),
-			  prog_func.myPktCall.begin(), std::toupper);
+			  prog_func.myPktCall.begin(), to_upper);
 	    }
 	    
 	    // look for "SELCALL:"
 	    else if (get_prog_parm("SELCALL:", file_read, prog_func.mySelCall)) {
 	        transform(prog_func.mySelCall.begin(), prog_func.mySelCall.end(),
-			  prog_func.mySelCall.begin(), std::toupper);
+			  prog_func.mySelCall.begin(), to_upper);
 	    }
 
 	    // look for "SERIALPORT:"
@@ -575,6 +576,7 @@ void configure_program(int& speed, string& port, int& vhf_paclen, int& hf_paclen
 	        "defaulting to lpr" << endl;
 	prog_func.print_cmd = "lpr";
     }
+    filein.clear();
     filein.close();
 }
 
@@ -1000,7 +1002,7 @@ void read_init(int& speed, string& port) {
       // look for "MY_CALL:"
       if (get_prog_parm("MY_CALL:", file_read, prog_func.myCall)) {
 	transform(prog_func.myCall.begin(), prog_func.myCall.end(),
-		  prog_func.myCall.begin(), std::toupper);
+		  prog_func.myCall.begin(), to_upper);
 	if (prog_func.myPktCall.empty()) { // only overwrite myPktCall if no PKT_CALL: yet specified
 	  prog_func.myPktCall = prog_func.myCall;
 	}
@@ -1009,13 +1011,13 @@ void read_init(int& speed, string& port) {
       // look for "PKT_CALL:"
       else if (get_prog_parm("PKT_CALL:", file_read, prog_func.myPktCall)) {
 	transform(prog_func.myPktCall.begin(), prog_func.myPktCall.end(),
-		  prog_func.myPktCall.begin(), std::toupper);
+		  prog_func.myPktCall.begin(), to_upper);
       }
 	    
       // look for "SELCALL:"
       else if (get_prog_parm("SELCALL:", file_read, prog_func.mySelCall)) {
 	transform(prog_func.mySelCall.begin(), prog_func.mySelCall.end(),
-		  prog_func.mySelCall.begin(), std::toupper);
+		  prog_func.mySelCall.begin(), to_upper);
       }
 
       // look for "SERIALPORT:"
