@@ -283,9 +283,9 @@ gint ConnectEditor::key_press_event_impl(GdkEventKey* event_p) {
     valid_flag = true;
   }
 
-  else if (keycode < 256 && isalnum((char)keycode)) {
-    *letter = toupper(*letter);
-    keycode = toupper(keycode);
+  else if (keycode < 256 && isalnum(static_cast<unsigned char> (keycode))) {
+    *letter = toupper(static_cast<unsigned char> (*letter));
+    keycode = toupper(static_cast<unsigned char> (keycode));
     valid_flag = true;
   }
 
@@ -372,6 +372,7 @@ void FileReadSelectDialog::selected(bool accept) {
       else {
         file.seekg(0, ios::end);
 	streampos size = file.tellg();
+	file.clear();
 	file.close(); // got the file size - now close it
 	file_to_read(filename, size);
 	finish();
@@ -622,8 +623,8 @@ gint CommandEditor::key_press_event_impl(GdkEventKey* event_p) {;
   else if (keycode >= 32 && keycode <= 127){
     if (count < COMMAND_SIZE || marked_text) {
       count++;
-      *letter = toupper(*letter);
-      keycode = toupper(keycode);
+      *letter = toupper(static_cast<unsigned char> (*letter));
+      keycode = toupper(static_cast<unsigned char> (keycode));
       valid_flag = true;
     }
     else beep();
@@ -741,9 +742,9 @@ gint CallsignEditor::key_press_event_impl(GdkEventKey* event_p) {
     valid_flag = true;
   }
 
-  else if (keycode < 256 && isalnum((char)keycode)) {
-    *letter = toupper(*letter);
-    keycode = toupper(keycode);
+  else if (keycode < 256 && isalnum(static_cast<unsigned char> (keycode))) {
+    *letter = toupper(static_cast<unsigned char> (*letter));
+    keycode = toupper(static_cast<unsigned char> (keycode));
     valid_flag = true;
   }
 
