@@ -24,6 +24,7 @@ COPYRIGHT distributed with the source files.
 #include "settings.h"
 #include "settings_icons.h"
 #include "modal_dialogs.h"
+#include "char_funcs.h"
 
 IdentityTable::IdentityTable(const int standard_size): Gtk::Table(5, 3, false), mycall_label("Callsign: "),
 				           mypacketcall_label("Packet Callsign: "), myselcall_label("Selcall: ") {
@@ -697,7 +698,7 @@ bool SettingsDialog::write_config(void) {
   }
   else {
     transform(temp.begin(), temp.end(),
-	      temp.begin(), std::toupper);
+	      temp.begin(), to_upper);
     mycall_line += temp;
   }
 
@@ -707,7 +708,7 @@ bool SettingsDialog::write_config(void) {
   if (temp.empty()) mypacketcall_line = "#PKT_CALL: ";
   else {
     transform(temp.begin(), temp.end(),
-	      temp.begin(), std::toupper);
+	      temp.begin(), to_upper);
     mypacketcall_line = "PKT_CALL: ";
     mypacketcall_line += temp;
   }
@@ -718,7 +719,7 @@ bool SettingsDialog::write_config(void) {
   if (temp.empty()) myselcall_line = "#SELCALL: ";
   else {
     transform(temp.begin(), temp.end(),
-	      temp.begin(), std::toupper);
+	      temp.begin(), to_upper);
     myselcall_line = "SELCALL: ";
     myselcall_line += temp;
   }
@@ -1147,21 +1148,21 @@ void SettingsDialog::read_config(bool search_localfile) {
 	  // look for "MY_CALL:"
 	  if (get_prog_parm("MY_CALL:", file_read, result)) {
 	    transform(result.begin(), result.end(),
-		      result.begin(), std::toupper);
+		      result.begin(), to_upper);
 	    identity_table.set_mycall(result);
 	  }
 	
 	  // look for "PKT_CALL:"
 	  else if (get_prog_parm("PKT_CALL:", file_read, result)) {
 	    transform(result.begin(), result.end(),
-		      result.begin(), std::toupper);
+		      result.begin(), to_upper);
 	    identity_table.set_mypacketcall(result);
 	  }
 	
 	  // look for "SELCALL:"
 	  else if (get_prog_parm("SELCALL:", file_read, result)) {
 	    transform(result.begin(), result.end(),
-		      result.begin(), std::toupper);
+		      result.begin(), to_upper);
 	    identity_table.set_myselcall(result);
 	  }
 	
@@ -1568,7 +1569,7 @@ bool IdentitySettingsDialog::write_config(void) {
   }
   else {
     transform(temp.begin(), temp.end(),
-	      temp.begin(), std::toupper);
+	      temp.begin(), to_upper);
     mycall_line += temp;
   }
 
@@ -1578,7 +1579,7 @@ bool IdentitySettingsDialog::write_config(void) {
   if (temp.empty()) mypacketcall_line = "#PKT_CALL: ";
   else {
     transform(temp.begin(), temp.end(),
-	      temp.begin(), std::toupper);
+	      temp.begin(), to_upper);
     mypacketcall_line = "PKT_CALL: ";
     mypacketcall_line += temp;
   }
@@ -1589,7 +1590,7 @@ bool IdentitySettingsDialog::write_config(void) {
   if (temp.empty()) myselcall_line = "#SELCALL: ";
   else {
     transform(temp.begin(), temp.end(),
-	      temp.begin(), std::toupper);
+	      temp.begin(), to_upper);
     myselcall_line = "SELCALL: ";
     myselcall_line += temp;
   }
