@@ -19,6 +19,7 @@ COPYRIGHT distributed with the source files.
 #include "receivewin.h"
 #include "download.h"
 #include "tnc.h"
+#include "char_funcs.h"
 
 // the following define set the amount of clear bytes in the Kam buffer that
 // will be left when send a file
@@ -1596,7 +1597,7 @@ void Tnc::find_call(char modemchar) {
 	        *message_ptr = 0;
 	    }
 	    for(message_ptr = callbuffer; *message_ptr != 0; message_ptr++) {  // convert to upper case
-	        *message_ptr = toupper(*message_ptr);
+	        *message_ptr = toupper(static_cast<unsigned char> (*message_ptr));
 	    }
 	    if (is_validcall(callbuffer)) {
 	        tnc_func.hisCall[0][1] = callbuffer;
@@ -1692,10 +1693,10 @@ void Tnc::make_selcall(const string& callsign,  string& selcall) {
     int lettercount;
     // get the letters at the end of the callsign
     for (pos = first_part.size() - 1, lettercount = 3; lettercount > 0 && static_cast<signed short>(pos) >= 0; pos--) {
-        if (isalpha(first_part[pos])) temp[lettercount--] = first_part[pos];
+        if (is_alpha(first_part[pos])) temp[lettercount--] = first_part[pos];
     }
     // now find the first letter of the callsign
-    string::iterator iter = find_if(first_part.begin(), first_part.end(), isalpha);
+    string::iterator iter = find_if(first_part.begin(), first_part.end(), is_alpha);
     while (lettercount >= 0) temp[lettercount--] = *iter;
     selcall = temp;
 }
